@@ -38,9 +38,14 @@ class CogEnvDecoder:
         self.depth_sock = U.UdpComms(udpIP="127.0.0.1", portTX=8002, portRX=8003,enableRX=True, suppressWarnings=True)
         self.last_frame = np.zeros((100, 100), dtype=np.uint8)
         self.last_depth_frame = np.zeros((100, 100), dtype=np.uint8)
-        data = open("RealGame_Data/data.txt", "w")
-        data.write(str(mat_num))
-        data.close()
+        if env_name == 'RealGame.exe':
+            data = open("RealGame_Data/data.txt", "w")
+            data.write(str(mat_num))
+            data.close()
+        elif env_name == '1.x86_64':
+            data = open("data.txt", "w")
+            data.write(str(mat_num))
+            data.close()
 
     @property
     def observation_space(self):
